<template>
  <div>
    <el-dialog
      title="选择合同信息"
      :visible.sync="dialogVisible"
      width="1000px"
      :close-on-click-modal="false"
      top="8vh"
      @close="closeDialog"
      v-if="dialogVisible"
      append-to-body
    >
      <el-container>
        <el-main style="padding: 10px; height: 400px">
          <ht-table
            @load="loadData"
            :data="data"
            :selectable="false"
            :highlightCurrentRow="true"
            :page-result="pageResult"
            quick-search-props="contract.name,contract.contractNumber"
            ref="htTable"
            :show-export="false"
            :show-custom-column="false"
            @row-click="rowClick"
          >
            <template v-slot:toolbar>
              <el-tooltip
                effect="dark"
                content="鼠标覆盖一条数据点击进行选取"
                placement="right"
              >
                <el-tag type="info">
                  <span class="el-icon-question">
                    提示
                  </span>
                </el-tag>
              </el-tooltip>
            </template>
            <template>
              <el-table-column
                type="selection"
                align="center"
                width="45"
                v-if="!this.single"
              ></el-table-column>
              <el-table-column
                align="center"
                width="50"
              >
                <template slot-scope="scope">
                  <el-radio
                    v-model="selectedId"
                    :label="scope.row.contract.id"
                  ></el-radio>
                </template>
              </el-table-column>
              <ht-table-column
                type="index"
                width="50"
                align="center"
                label="序号"
              />
              <el-table-column
                prop="contract.name"
                label="合同名称"
                :show-overflow-tooltip="true"
                align="center"
              >
              </el-table-column>
              <el-table-column
                prop="contract.contractNumber"
                label="合同编号"
                :show-overflow-tooltip="true"
                align="center"
              >
              </el-table-column>
              <ht-table-column
                prop="contract.type"
                label="合同类别"
                :show-overflow-tooltip="true"
                align="center"
                :filters="getDictData('htgl-htlb')"
              >
                <template slot-scope="scope">
                  <div> {{ scope.row.contract.typeValue }}</div>
                  <!-- <div>{{ getDictName('htgl-htlb', scope.row.contract.type) }}</div> -->
                </template>
              </ht-table-column>
              <el-table-column
                prop="contract.contractAmount"
                label="合同金额(元)"
                :show-overflow-tooltip="true"
                align="center"
              >
              </el-table-column>

            </template>
          </ht-table>
        </el-main>
      </el-container>
      <span
        slot="footer"
        class="dialog-footer"
      >
        <el-button
          @click="closeDialog"
          size="medium"
        >取 消</el-button>
        <el-button
          type="primary"
          @click="handleOK"
          size="medium"
        >确 定</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import req from '@/request.js'
import basicData from '@/api/basicData.js'
import utils from '@/hotent-ui-util.js'
export default {
  name: 'ContractInfoDialog',
  components: {},
  props: {
    single: {
      type: Boolean,
      default: false
    }
    // projectId:''
  },
  data() {
    return {
      dialogVisible: false,
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      data: [],
      activeRow: {},
      selectedId: null,
      projectId: ''
      // pid:''
    }
  },
  // watch:{
  //   projectId:{
  //     immediate:true,
  //     handler(newval,oldval){
  //       console.log(newval,oldval)
  //       this.pid=newval
  //     }
  //   }
  // },
  methods: {
    rowClick(row) {
      this.activeRow = row.contract
      this.selectedId = row.contract.id
    },
    open(id) {
      this.dialogVisible = true
      this.projectId = id
      // this.$nextTick(()=>{
      //     this.$refs.htTable.load()
      // })
    },
    handleOK() {
      let selectRow = utils.deepClone(this.activeRow)
      console.log(selectRow)
      this.$emit('handleContract', selectRow)
      this.selectedId = null
      this.dialogVisible = false
      this.activeRow = {}
    },
    loadData(param, cb) {
      let projectId = [
        {
          group: 'advance',
          operation: 'LIKE',
          parentGroup: '',
          property: 'project_id_',
          relation: 'AND',
          value: this.projectId
        }
      ]
      if (param.querys) {
        param.querys = [...projectId, ...param.querys]
      } else {
        param.querys = projectId
      }
      param.querys && param.querys.forEach(item => {
        if (item.property == 'contract.name') {
          item.property = 'bc.name_'
        }else if(item.property == 'contract.contractNumber'){
          item.property = 'bc.contract_number_'
        }
      })
      this.$http
        .post('${cqxy}/biz/contract/v1/page', param)
        .then(
          resp => {
            let response = resp.data.value
            this.data = response.rows
            this.pageResult = {
              page: response.page,
              pageSize: response.pageSize,
              total: response.total
            }
          },
          error => {
            reject(error)
          }
        )
        .finally(() => {
          if (cb) {
            cb()
          }
        })
    },
    closeDialog() {
      this.dialogVisible = false
      this.activeRow = {}
    }
  }
}
</script>

<style lang="scss" scoped>
>>> .el-dialog__body {
  padding-bottom: 0px !important;
}
/deep/ .el-dialog__header {
  border-bottom: 1px solid #ebeef5;
}
</style>